@@ -65,10 +65,9 @@ class About_Dialog(QDialog):
 
     def __init__(self):
         """
-        Displays "About" dialog.
+        Initializes "About" dialog.
         """
 
-        # noinspection PyArgumentList
         QDialog.__init__(self)
 
         self.setWindowTitle("About")
@@ -76,6 +75,8 @@ class About_Dialog(QDialog):
         layout = QVBoxLayout()
         self.setLayout(layout)
 
+        # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+
         text_browser = QTextBrowser()
         text_browser.setMinimumWidth(self.Width)
         text_browser.setMinimumHeight(self.Height)
@@ -89,6 +90,8 @@ class About_Dialog(QDialog):
         text_browser.setFocusPolicy(Qt.NoFocus)
         layout.addWidget(text_browser)
 
+        # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+
         button_box = QHBoxLayout()
 
         ok_button = QPushButton(qta.icon("fa.check"), "OK")
@@ -101,6 +104,8 @@ class About_Dialog(QDialog):
 
         layout.addLayout(button_box)
 
+    # ------------------------------------------------------------------------------------------------------------------
+
     def show(self):
         """
         Shows this dialog.
