@@ -16,6 +16,7 @@
 #  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 #  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
+import numpy as np
 from si_prefix import si_format
 from PyQt5.QtCore import Qt
 from PyQt5.QtWidgets import QVBoxLayout, QHBoxLayout, QLabel, QSizePolicy
@@ -143,23 +144,33 @@ class Parameters_Widget(Groupbox):
 
                 # Field is B-field (flux density)
 
-                energy_value = si_format(self.gui.model.parameters.get_energy(), precision=self.ValuePrecision) + "J"
+                energy_value = self.gui.model.parameters.get_energy()
+                if np.isnan(energy_value):
+                    energy_value = "NaN "
+                else:
+                    energy_value = si_format(energy_value, precision=self.ValuePrecision) + "J"
                 self.energy_value_label.setText(energy_value.split(" ")[0])
                 self.energy_value_label.setStyleSheet(f"color: {Theme.PrimaryColor}; font-weight: bold;")
                 self.energy_units_label.setText(energy_value.split(" ")[1])
                 self.energy_units_label.setStyleSheet(f"color: {Theme.PrimaryColor}; font-weight: bold;")
 
-                self_inductance_value = si_format(
-                    self.gui.model.parameters.get_self_inductance(), precision=self.ValuePrecision
-                ) + "H"
+                self_inductance_value = self.gui.model.parameters.get_self_inductance()
+                if np.isnan(self_inductance_value):
+                    self_inductance_value = "NaN "
+                else:
+                    self_inductance_value = si_format(self_inductance_value, precision=self.ValuePrecision) + "H"
                 self.self_inductance_value_label.setText(self_inductance_value.split(" ")[0])
                 self.self_inductance_value_label.setStyleSheet(f"color: {Theme.PrimaryColor}; font-weight: bold;")
                 self.self_inductance_units_label.setText(self_inductance_value.split(" ")[1])
                 self.self_inductance_units_label.setStyleSheet(f"color: {Theme.PrimaryColor}; font-weight: bold;")
 
-                magnetic_dipole_moment_value = si_format(
-                    self.gui.model.parameters.get_magnetic_dipole_moment(), precision=self.ValuePrecision
-                ) + "Am²"
+                magnetic_dipole_moment_value = self.gui.model.parameters.get_magnetic_dipole_moment()
+                if np.isnan(magnetic_dipole_moment_value):
+                    magnetic_dipole_moment_value = "NaN "
+                else:
+                    magnetic_dipole_moment_value = si_format(
+                        magnetic_dipole_moment_value, precision=self.ValuePrecision
+                    ) + "Am²"
                 self.magnetic_dipole_moment_value_label.setText(magnetic_dipole_moment_value.split(" ")[0])
                 self.magnetic_dipole_moment_value_label.setStyleSheet(
                     f"color: {Theme.PrimaryColor}; font-weight: bold;"
