@@ -21,6 +21,7 @@ from PyQt5.QtWidgets import QWidget, QScrollArea, QVBoxLayout, QSizePolicy
 from magneticalc.Display_Widget import Display_Widget
 from magneticalc.Field_Widget import Field_Widget
 from magneticalc.Metric_Widget import Metric_Widget
+from magneticalc.Parameters_Widget import Parameters_Widget
 from magneticalc.Perspective_Widget import Perspective_Widget
 
 
@@ -28,7 +29,7 @@ class SidebarRight(QScrollArea):
     """ SidebarRight class. """
 
     # Display settings
-    MaximumWidth = 380
+    MaximumWidth = 370
     VerticalSpacing = 12
 
     def __init__(self, gui):
@@ -42,7 +43,6 @@ class SidebarRight(QScrollArea):
         self.gui = gui
 
         layout = QVBoxLayout()
-        # noinspection PyArgumentList
         widget = QWidget()
         widget.setLayout(layout)
         self.setWidget(widget)
@@ -52,28 +52,35 @@ class SidebarRight(QScrollArea):
         self.setMaximumWidth(self.MaximumWidth)
         self.setSizePolicy(QSizePolicy.Fixed, QSizePolicy.Expanding)
 
-        # --------------------------------------------------------------------------------------------------------------
+        # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
         self.field_widget = Field_Widget(self.gui)
         layout.addWidget(self.field_widget, alignment=Qt.AlignTop)
 
         layout.addSpacing(self.VerticalSpacing)
 
-        # --------------------------------------------------------------------------------------------------------------
+        # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
         self.metric_widget = Metric_Widget(self.gui)
         layout.addWidget(self.metric_widget, alignment=Qt.AlignTop)
 
         layout.addSpacing(self.VerticalSpacing)
 
-        # --------------------------------------------------------------------------------------------------------------
+        # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+
+        self.parameters_widget = Parameters_Widget(self.gui)
+        layout.addWidget(self.parameters_widget, alignment=Qt.AlignTop)
+
+        layout.addSpacing(self.VerticalSpacing)
+
+        # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
         self.perspective_widget = Perspective_Widget(self.gui)
         layout.addWidget(self.perspective_widget, alignment=Qt.AlignTop)
 
         layout.addSpacing(self.VerticalSpacing)
 
-        # --------------------------------------------------------------------------------------------------------------
+        # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
         self.display_widget = Display_Widget(self.gui)
         layout.addWidget(self.display_widget, alignment=Qt.AlignTop)
