@@ -58,8 +58,8 @@ class Usage_Dialog(QDialog):
         <ul>
             <li>
                 Select the type of field to calculate:
-                <b>A</b>-field (vector potential) or
-                <b>B</b>-field (flux density).
+                A-field (vector potential) or
+                B-field (flux density).
             </li>
             <li>
                 Current element center points may be located very close to sampling volume points;<br>
@@ -91,20 +91,21 @@ class Usage_Dialog(QDialog):
             <li>If you like the result, press CTRL+S to save a screenshot!</li>
         </ul>
 
-        All settings (including your wire shape) are stored in the <code>MagnetiCalc.ini</code> file.<br>
+        All settings (including your wire shape) are stored in the <code>MagnetiCalc.ini</code> file by default.<br>
         Deleting or renaming this file will restore the default settings.
 
         <h3 style="color: {Theme.PrimaryColor};">What does MagnetiCalc do?</h3>
 
-        MagnetiCalc calculates the magnetic flux density, vector potential, energy, self-inductance
-        and magnetic dipole moment of arbitrary coils in vacuum.
-        As an experimental feature, different core media can be modeled as regions of variable relative permeability.
-        <br><br>
+        MagnetiCalc calculates the static magnetic flux density, vector potential, energy, self-inductance
+        and magnetic dipole moment of arbitrary coils.
+        Inside a VisPy / OpenGL-accelerated PyQt5 GUI, the magnetic flux density
+        (B-field, in units of <i>Tesla</i>)
+        or the magnetic vector potential (A-field, in units of <i>Tesla-meter</i>)
+        is displayed in interactive 3D, using multiple metrics for highlighting this field's properties.<br><br>
 
-        Inside a VisPy/OpenGL-accelerated PyQt5 GUI, the static magnetic flux density
-        (<b>B</b>-field due to a DC current, in units of <i>Tesla</i>)
-        or the magnetic vector potential (<b>A</b>-field, in units of <i>Tesla-meter</i>)
-        is displayed in interactive 3D, using multiple metrics for highlighting this field's properties.
+        <i>Experimental feature:</i> To calculate the energy and self-inductance of permeable (i.e. ferromagnetic)
+        materials, different core media can be modeled as regions of variable relative permeability;
+        however, core saturation is currently not modeled, leading to excessive flux density values.
 
         <h3 style="color: {Theme.PrimaryColor};">Who needs MagnetiCalc?</h3>
 
@@ -114,11 +115,12 @@ class Usage_Dialog(QDialog):
 
         <h3 style="color: {Theme.PrimaryColor};">How does it work?</h3>
 
-        The <b>B</b>-field calculation is implemented using the Biot-Savart law [1],
+        The B-field calculation is implemented using the Biot-Savart law [1],
         employing multiprocessing techniques;
         MagnetiCalc uses just-in-time compilation (JIT/Numba) to achieve high-performance calculations.
         Additionally, the use of easily constrainable "sampling volumes"
-        allows for selective calculation over grids of arbitrary shape and arbitrary relative permeabilities.<br><br>
+        allows for selective calculation over grids of arbitrary shape and arbitrary relative permeabilities
+        <i>(experimental)</i>.<br><br>
 
         The shape of any wire is modeled as a 3D piecewise linear curve.
         Arbitrary loops of wire are sliced into differential current elements, each of which
@@ -129,14 +131,15 @@ class Usage_Dialog(QDialog):
         field color and alpha transparency are individually mapped using one of the various available metrics.<br><br>
 
         The coil's energy [2] and self-inductance [3]
-        are calculated by summing the squared <b>B</b>-field over the entire sampling volume;
+        are calculated by summing the squared B-field over the entire sampling volume;
         ensure that the sampling volume encloses a large, non-singular portion of the field.<br><br>
 
-        Additionally, the scalar magnetic dipole moment is calculated by summing over all current elements.<br><br>
+        Additionally, the scalar magnetic dipole moment [4] is calculated by summing over all current elements.<br><br>
 
         [1]: Jackson, Klassische Elektrodynamik, 5. Auflage, S. 204, (5.4).<br>
         [2]: Kraus, Electromagnetics, 4th Edition, p. 269, 6-9-1.<br>
         [3]: Jackson, Klassische Elektrodynamik, 5. Auflage, S. 252, (5.157).<br>
+        [4]: Jackson, Klassische Elektrodynamik, 5. Auflage, S. 216, (5.54).<br>
 
         <br><br><span style="color: {Theme.PrimaryColor};">
             This and more information about MagnetiCalc can be found in the <code>README.md</code> file.
